==> docx4j-openxml-objects-sml-8.3.3-sources.jar: org/xlsx4j/sml/CTFunctionGroups.java <==
/*
 *  Copyright 2010-2013, Plutext Pty Ltd.
 *   
 *  This file is part of xlsx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.xlsx4j.sml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_FunctionGroups complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_FunctionGroups">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="unbounded">
 *         &lt;element name="functionGroup" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_FunctionGroup" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="builtInGroupCount" type="{http://www.w3.org/2001/XMLSchema}unsignedInt" default="16" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_FunctionGroups", propOrder = {
    "functionGroup"
})
public class CTFunctionGroups implements Child
{

    protected List<CTFunctionGroup> functionGroup;
    @XmlAttribute(name = "builtInGroupCount")
    @XmlSchemaType(name = "unsignedInt")
    protected Long builtInGroupCount;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the functionGroup property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the functionGroup property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFunctionGroup().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTFunctionGroup }
     * 
     * 
     */
    public List<CTFunctionGroup> getFunctionGroup() {
        if (functionGroup == null) {
            functionGroup = new ArrayList<CTFunctionGroup>();
        }
        return this.functionGroup;
    }

    /**
     * Gets the value of the builtInGroupCount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public long getBuiltInGroupCount() {
        if (builtInGroupCount == null) {
            return  16L;
        } else {
            return builtInGroupCount;
        }
    }

    /**
     * Sets the value of the builtInGroupCount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setBuiltInGroupCount(Long value) {
        this.builtInGroupCount = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> docx4j-openxml-objects-sml-11.4.9-sources.jar: org/xlsx4j/sml/CTFunctionGroups.java <==
/*
 *  Copyright 2010-2013, Plutext Pty Ltd.
 *   
 *  This file is part of xlsx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.xlsx4j.sml;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.Unmarshaller;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlTransient;
import jakarta.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_FunctionGroups complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_FunctionGroups">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="unbounded">
 *         &lt;element name="functionGroup" type="{http://schemas.openxmlformats.org/spreadsheetml/2006/main}CT_FunctionGroup" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="builtInGroupCount" type="{http://www.w3.org/2001/XMLSchema}unsignedInt" default="16" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_FunctionGroups", propOrder = {
    "functionGroup"
})
public class CTFunctionGroups implements Child
{

    protected List<CTFunctionGroup> functionGroup;
    @XmlAttribute(name = "builtInGroupCount")
    @XmlSchemaType(name = "unsignedInt")
    protected Long builtInGroupCount;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the functionGroup property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the functionGroup property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getFunctionGroup().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link CTFunctionGroup }
     * 
     * 
     */
    public List<CTFunctionGroup> getFunctionGroup() {
        if (functionGroup == null) {
            functionGroup = new ArrayList<CTFunctionGroup>();
        }
        return this.functionGroup;
    }

    /**
     * Gets the value of the builtInGroupCount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public long getBuiltInGroupCount() {
        if (builtInGroupCount == null) {
            return  16L;
        } else {
            return builtInGroupCount;
        }
    }

    /**
     * Sets the value of the builtInGroupCount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setBuiltInGroupCount(Long value) {
        this.builtInGroupCount = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}
